@@ -4,11 +4,14 @@ import json
 import base64
 import hashlib
 import hmac
+import decimal
+import warnings
 
 from . import exceptions
 from requests_oauthlib import OAuth2Session
 
-to_bytes = lambda value, *args, **kwargs: bytes(value, "utf-8", *args, **kwargs)
+def to_bytes(value, *args, **kwargs):
+    return bytes(value, "utf-8", *args, **kwargs)
 
 
 class Environments(object):
@@ -17,6 +20,7 @@ class Environments(object):
 
 
 class QuickBooks(object):
+    MINIMUM_MINOR_VERSION = 75
     company_id = 0
     session = None
     auth_client = None
@@ -24,6 +28,7 @@ class QuickBooks(object):
     minorversion = None
     verifier_token = None
     invoice_link = False
+    use_decimal = False
 
     sandbox_api_url_v3 = "https://sandbox-quickbooks.api.intuit.com/v3"
     api_url_v3 = "https://quickbooks.api.intuit.com/v3"
@@ -74,11 +79,20 @@ class QuickBooks(object):
         if 'minorversion' in kwargs:
             instance.minorversion = kwargs['minorversion']
 
+            if instance.minorversion < instance.MINIMUM_MINOR_VERSION:
+                warnings.warn(
+                    'Minor Version no longer supported.'
+                    'See: https://blogs.intuit.com/2025/01/21/changes-to-our-accounting-api-that-may-impact-your-application/',
+                    DeprecationWarning)
+
         instance.invoice_link = kwargs.get('invoice_link', False)
 
         if 'verifier_token' in kwargs:
             instance.verifier_token = kwargs.get('verifier_token')
 
+        if 'use_decimal' in kwargs:
+            instance.use_decimal = kwargs.get('use_decimal')
+
         return instance
 
     def _start_session(self):
@@ -149,9 +163,6 @@ class QuickBooks(object):
         if request_id:
             params['requestid'] = request_id
 
-        if self.invoice_link:
-            params['include'] = 'invoiceLink'
-
         if not request_body:
             request_body = {}
 
@@ -206,7 +217,10 @@ class QuickBooks(object):
                 "Application authentication failed", error_code=req.status_code, detail=req.text)
 
         try:
-            result = req.json()
+            if (self.use_decimal):
+                result = json.loads(req.text, parse_float=decimal.Decimal)
+            else:
+                result = json.loads(req.text)
         except:
             raise exceptions.QuickbooksException("Error reading json response: {0}".format(req.text), 10000)
 
@@ -233,9 +247,9 @@ class QuickBooks(object):
         return self.session.request(
             request_type, url, headers=headers, params=params, data=data)
 
-    def get_single_object(self, qbbo, pk):
+    def get_single_object(self, qbbo, pk, params=None):
         url = "{0}/company/{1}/{2}/{3}/".format(self.api_url, self.company_id, qbbo.lower(), pk)
-        result = self.get(url, {})
+        result = self.get(url, {}, params=params)
 
         return result
 
