@@ -1,23 +1,27 @@
+import decimal
+import json
 from urllib.parse import quote
 
-try: import simplejson as json
-except ImportError: import json
-
-from .utils import build_where_clause, build_choose_clause
 from .client import QuickBooks
 from .exceptions import QuickbooksException
+from .utils import build_choose_clause, build_where_clause
 
+class DecimalEncoder(json.JSONEncoder):
+    def default(self, o):
+        if isinstance(o, decimal.Decimal):
+            return str(o)
+        return super(DecimalEncoder, self).default(o)
 
 class ToJsonMixin(object):
     def to_json(self):
-        return json.dumps(self, default=self.json_filter(), sort_keys=True, indent=4)
+        return json.dumps(self, cls=DecimalEncoder, default=self.json_filter(), sort_keys=True, indent=4)
 
     def json_filter(self):
         """
         filter out properties that have names starting with _
         or properties that have a value of None
         """
-        return lambda obj: dict((k, v) for k, v in obj.__dict__.items()
+        return lambda obj: str(obj) if isinstance(obj, decimal.Decimal) else dict((k, v) for k, v in obj.__dict__.items()
                                 if not k.startswith('_') and getattr(obj, k) is not None)
 
 
@@ -90,11 +94,11 @@ class ReadMixin(object):
     qbo_json_object_name = ""
 
     @classmethod
-    def get(cls, id, qb=None):
+    def get(cls, id, qb=None, params=None):
         if not qb:
             qb = QuickBooks()
 
-        json_data = qb.get_single_object(cls.qbo_object_name, pk=id)
+        json_data = qb.get_single_object(cls.qbo_object_name, pk=id, params=params)
 
         if cls.qbo_json_object_name != '':
             return cls.from_json(json_data[cls.qbo_json_object_name])
@@ -178,7 +182,7 @@ class VoidMixin(object):
 
         data = self.get_void_data()
         params = self.get_void_params()
-        results = qb.post(url, json.dumps(data), params=params)
+        results = qb.post(url, json.dumps(data, cls=DecimalEncoder), params=params)
 
         return results
 
@@ -232,7 +236,7 @@ class DeleteMixin(object):
             'Id': self.Id,
             'SyncToken': self.SyncToken,
         }
-        return qb.delete_object(self.qbo_object_name, json.dumps(data), request_id=request_id)
+        return qb.delete_object(self.qbo_object_name, json.dumps(data, cls=DecimalEncoder), request_id=request_id)
 
 
 class DeleteNoIdMixin(object):
