@@ -35,6 +35,6 @@ class CompanyCurrency(QuickbooksManagedObject, QuickbooksTransactionEntity):
 
         ref.name = self.Name
         ref.type = self.qbo_object_name
-        ref.value = self.Id
+        ref.value = self.Code
 
         return ref
