@@ -1,8 +1,6 @@
-from six import python_2_unicode_compatible
 from .base import QuickbooksManagedObject, QuickbooksTransactionEntity, Ref
 
 
-@python_2_unicode_compatible
 class PaymentMethod(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: The PaymentMethod entity provides the method of payment for received goods. Delete is achieved by setting the
@@ -29,3 +27,5 @@ class PaymentMethod(QuickbooksManagedObject, QuickbooksTransactionEntity):
         ref.name = self.Name
         ref.type = self.qbo_object_name
         ref.value = self.Id
+
+        return ref
